@@ -16,10 +16,10 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301  USA.
  *
- * $Id: totemBasicPlugin.cpp 5024 2008-01-15 23:43:31Z hadess $
+ * $Id: totemBasicPlugin.cpp 5397 2008-05-08 16:30:50Z hadess $
  */
 
 #include <mozilla-config.h>
@@ -64,6 +64,7 @@ static const totemPluginMimeEntry kMimeTypes[] = {
 	{ "audio/mpeg", "mp3", NULL },
 	{ "application/x-nsv-vp3-mp3", "nsv", "video/x-nsv" },
 	{ "video/flv", "flv", "application/x-flash-video" },
+	{ "application/x-totem-plugin", "", "application/octet-stream" },
 };
 
 totemScriptablePlugin::totemScriptablePlugin (totemPlugin *aPlugin)
@@ -83,6 +84,12 @@ totemScriptablePlugin::PluginDescription ()
   return (char*) kPluginDescription;
 }
 
+/* static */ char *
+totemScriptablePlugin::PluginLongDescription ()
+{
+  return (char*) totem_plugin_get_long_description();
+}
+
 /* static */ void
 totemScriptablePlugin::PluginMimeTypes (const totemPluginMimeEntry **_entries,
 					PRUint32 *_count)
