@@ -16,16 +16,14 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301  USA.
  */
 
 #include <mozilla-config.h>
 #include "config.h"
 
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include <libgnomevfs/gnome-vfs-mime-info.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gio/gio.h>
 #include <dlfcn.h>
 
 #include "npapi.h"
@@ -203,7 +201,7 @@ totem_plugin_print (NPP instance,
 	D ("Print");
 }
 
-char *
+const char *
 totem_plugin_get_long_description (void)
 {
 	return "The <a href=\"http://www.gnome.org/projects/totem/\">Totem</a> " PACKAGE_VERSION " plugin handles video and audio streams.";
@@ -353,9 +351,8 @@ NP_GetMIMEDescription (void)
 	}
 
 	char *user_ini_file;
-	user_ini_file = g_build_filename (g_get_home_dir (),
-					  ".gnome2",
-					  "Totem",
+	user_ini_file = g_build_filename (g_get_user_config_dir (),
+					  "totem",
 					  "browser-plugins.ini",
 					  NULL);
 	if (g_key_file_load_from_file (user,
@@ -371,24 +368,25 @@ NP_GetMIMEDescription (void)
 	PRUint32 count;
 	totemScriptablePlugin::PluginMimeTypes (&mimetypes, &count);
 	for (PRUint32 i = 0; i < count; ++i) {
-		const char *desc;
+		char *desc;
 
 		if (totem_plugin_mimetype_is_disabled (mimetypes[i].mimetype, system, user))
 			continue;
 
-		desc = gnome_vfs_mime_get_description (mimetypes[i].mimetype);
+		desc = g_content_type_get_description (mimetypes[i].mimetype);
 		if (desc == NULL && mimetypes[i].mime_alias != NULL) {
-			desc = gnome_vfs_mime_get_description
+			desc = g_content_type_get_description
 				(mimetypes[i].mime_alias);
 		}
 		if (desc == NULL) {
-			desc = mimetypes[i].mime_alias;
+			desc = g_strdup (mimetypes[i].mime_alias);
 		}
 
 		g_string_append_printf (list,"%s:%s:%s;",
 					mimetypes[i].mimetype,
 					mimetypes[i].extensions,
 					desc ? desc : "-");
+		g_free (desc);
 	}
 
 	mime_list = g_string_free (list, FALSE);
